aboutsummaryrefslogtreecommitdiffstats
path: root/core/consensus_test.go
diff options
context:
space:
mode:
authorWei-Ning Huang <w@dexon.org>2018-09-19 18:48:41 +0800
committermissionliao <38416648+missionliao@users.noreply.github.com>2018-09-19 18:48:41 +0800
commit22e70f6da486ed6796a493f25e04679b9afa1439 (patch)
tree41998daa892812957daa58d7fe84d6fd06f4327c /core/consensus_test.go
parenta2a733e6f98018cb2ecc4b3982386be8892d7433 (diff)
downloaddexon-consensus-22e70f6da486ed6796a493f25e04679b9afa1439.tar.gz
dexon-consensus-22e70f6da486ed6796a493f25e04679b9afa1439.tar.zst
dexon-consensus-22e70f6da486ed6796a493f25e04679b9afa1439.zip
core: rename Notary (Acks) to Witness (#118)
Diffstat (limited to 'core/consensus_test.go')
-rw-r--r--core/consensus_test.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/core/consensus_test.go b/core/consensus_test.go
index dd64cc2..32f9986 100644
--- a/core/consensus_test.go
+++ b/core/consensus_test.go
@@ -41,8 +41,8 @@ func (n *network) BroadcastVote(vote *types.Vote) {}
func (n *network) BroadcastBlock(block *types.Block) {
}
-// BroadcastNotaryAck broadcasts notaryAck to all nodes in DEXON network.
-func (n *network) BroadcastNotaryAck(notaryAck *types.NotaryAck) {
+// BroadcastWitnessAck broadcasts witnessAck to all nodes in DEXON network.
+func (n *network) BroadcastWitnessAck(witnessAck *types.WitnessAck) {
}
// SendDKGPrivateShare sends PrivateShare to a DKG participant.